==> jc-1.4.0.tar.gz: org/w3c/dom/bootstrap/DOMImplementationRegistry__242.c <==
// final class org.w3c.dom.bootstrap.DOMImplementationRegistry$2

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 26b8d7b7a241db31 java_lang_ClassLoader
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 767fc1626c63609e java_lang_SecurityException
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class a3a7cdc3e4c7ce28 java_lang_Thread
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 8ee50e5570e2a2e1 java_lang_VMThread
// @dep_class fe58a8cfe9b5b994 java_security_PrivilegedAction
// @dep_class 6b32cb9646ebd038 org_w3c_dom_bootstrap_DOMImplementationRegistry__242

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_ClassLoader
// @dep_header java_lang_SecurityException
// @dep_header java_lang_String
// @dep_header java_lang_Thread
// @dep_header java_lang_VMThread
// @dep_header java_security_PrivilegedAction
// @dep_header org_w3c_dom_bootstrap_DOMImplementationRegistry__242

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/ClassLoader.h"
#include "java/lang/SecurityException.h"
#include "java/lang/String.h"
#include "java/lang/Thread.h"
#include "java/lang/VMThread.h"
#include "java/security/PrivilegedAction.h"
#include "org/w3c/dom/bootstrap/DOMImplementationRegistry__242.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>()
//

static _jc_linenum _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		0,
	.function=		&_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(org_w3c_dom_bootstrap_DOMImplementationRegistry__242, _init$52f4ad9f2989aeee);

void
_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$object *this)
{
	struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(321);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public final java.lang.Object run()
//

static _jc_linenum _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$linenum_table$run$b190d7b16d5785b8[];

static _jc_trap_info _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$trap_table$run$b190d7b16d5785b8[] = {
	_JC_TRAP(&_jc_java_lang_SecurityException$type, 1, 2),
};

static const unsigned char _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$param_ptypes$run$b190d7b16d5785b8[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$method_info$run$b190d7b16d5785b8 = {
	.name=			"run",
	.signature=		"()Ljava/lang/Object;",
	.class=			&_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$type,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$param_ptypes$run$b190d7b16d5785b8,
	.signature_hash=	_JC_JLONG(0xb190d7b16d5785b8),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.function=		&_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$method$run$b190d7b16d5785b8,
	.vtable_index=		_JC_OFFSETOF(struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$vtable, org_w3c_dom_bootstrap_DOMImplementationRegistry__242.run$b190d7b16d5785b8) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .trap_table_len=	1,
	  .trap_table=		_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$trap_table$run$b190d7b16d5785b8,
	  .u= {
	    .linenum= {
	      .len=	3,
	      .table=	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$linenum_table$run$b190d7b16d5785b8
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(org_w3c_dom_bootstrap_DOMImplementationRegistry__242, run$b190d7b16d5785b8);

_jc_java_lang_Object$object *
_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$method$run$b190d7b16d5785b8(_jc_env *const env, _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$object *this)
{
	struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$object *r0;
	struct _jc_java_lang_ClassLoader$object *volatile r1;
	struct _jc_java_lang_SecurityException$object *r3;
	struct _jc_java_lang_Thread$object *r4;
	_jc_catch_frame	catch;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	// Define exception targets
	_JC_DEFINE_TRAPS(env, catch, &_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$method_info$run$b190d7b16d5785b8, &&label0);

	r0 = this;
	_JC_LINE_NUMBER(323);				// 0
	r1 = _JC_NULL;
	_JC_TRAP_REGION(catch, 1);
	_JC_ACTIVE_USE(env, java_lang_Thread);
	_JC_LINE_NUMBER(325);				// 1
	r4 = _JC_INVOKE_STATIC(env, java_lang_VMThread, currentThread$d66ed2ac560d4c84, 0);
	r1 = _JC_INVOKE_VIRTUAL(env, java_lang_Thread, getContextClassLoader$8df97c408c9fbc5d, r4);
	_JC_TRAP_REGION(catch, 2);
	goto label1;

label0:
	_JC_TRAP_REGION(catch, 2);
	r3 = _JC_CAUGHT_EXCEPTION(env);

label1:
	_JC_LINE_NUMBER(329);				// 2
	_JC_CANCEL_TRAPS(env, catch);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$methods[] = {
	&_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$method_info$_init$52f4ad9f2989aeee,
	&_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$method_info$run$b190d7b16d5785b8
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$interfaces[] = {
	&_jc_java_security_PrivilegedAction$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$imethod_hash_bucket_56[] = {
	&_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$method_info$run$b190d7b16d5785b8,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[56]=	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$imethod_hash_bucket_56
};

// Interface "quick" lookup hash table
static const void *_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[56]=	&_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$method$run$b190d7b16d5785b8
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$instanceof_hash_bucket_20[] = {
	&_jc_java_security_PrivilegedAction$type,
	_JC_NULL
};
static _jc_type *const _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$instanceof_hash_bucket_56[] = {
	&_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$type,
	_JC_NULL
};
static _jc_type *const _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[20]=	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$instanceof_hash_bucket_20,
	[56]=	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$instanceof_hash_bucket_56,
	[113]=	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/ClassLoader",	_JC_JLONG(0x26b8d7b7a241db31) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/SecurityException",	_JC_JLONG(0x767fc1626c63609e) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/lang/Thread",	_JC_JLONG(0xa3a7cdc3e4c7ce28) },
	{ "java/lang/Throwable",	_JC_JLONG(0x3be5c3c4fdd59a1e) },
	{ "java/lang/VMThread",	_JC_JLONG(0x8ee50e5570e2a2e1) },
	{ "java/security/PrivilegedAction",	_JC_JLONG(0xfe58a8cfe9b5b994) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$vtype _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$type = {
    .type= {
	.name=			"org/w3c/dom/bootstrap/DOMImplementationRegistry$2",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_FINAL,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$interfaces) / sizeof(*_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$interfaces),
	.interfaces=		_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$interfaces,
	.imethod_hash_table=	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$imethod_hash_table,
	.imethod_quick_table=	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x6b32cb9646ebd038),
		.source_file=		"DOMImplementationRegistry.java",
		.instance_size=		sizeof(_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$refs) + sizeof(_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$methods) / sizeof(*_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$methods),
		.methods=		_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$methods,
		.instanceof_hash_table=	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$class_depends) / sizeof(*_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$class_depends),
		.class_depends=		_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.org_w3c_dom_bootstrap_DOMImplementationRegistry__242= {
	    .run$b190d7b16d5785b8=
		&_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$method$run$b190d7b16d5785b8,
	},
    }
};

==> jc-1.4.5.tar.gz: org/w3c/dom/bootstrap/DOMImplementationRegistry__242.c <==
// final class org.w3c.dom.bootstrap.DOMImplementationRegistry$2

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 58c6b9c5ce1fc756 java_lang_ClassLoader
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 767fc1626c63609e java_lang_SecurityException
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 7e33d4feabbc3f15 java_lang_Thread
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 8ee50e5570e2a2e1 java_lang_VMThread
// @dep_class fe58a8cfe9b5b994 java_security_PrivilegedAction
// @dep_class 6b32cb9646ebd038 org_w3c_dom_bootstrap_DOMImplementationRegistry__242

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_ClassLoader
// @dep_header java_lang_SecurityException
// @dep_header java_lang_String
// @dep_header java_lang_Thread
// @dep_header java_lang_VMThread
// @dep_header java_security_PrivilegedAction
// @dep_header org_w3c_dom_bootstrap_DOMImplementationRegistry__242

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/ClassLoader.h"
#include "java/lang/SecurityException.h"
#include "java/lang/String.h"
#include "java/lang/Thread.h"
#include "java/lang/VMThread.h"
#include "java/security/PrivilegedAction.h"
#include "org/w3c/dom/bootstrap/DOMImplementationRegistry__242.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>()
//

static _jc_linenum _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		0,
	.function=		&_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(org_w3c_dom_bootstrap_DOMImplementationRegistry__242, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$object *this)
{
	struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(321);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public final java.lang.Object run()
//

static _jc_linenum _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$linenum_table$run$b190d7b16d5785b8[];

static _jc_trap_info _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$trap_table$run$b190d7b16d5785b8[] = {
	_JC_TRAP(&_jc_java_lang_SecurityException$type, 1, 2),
};

static const unsigned char _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$param_ptypes$run$b190d7b16d5785b8[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$method_info$run$b190d7b16d5785b8 = {
	.name=			"run",
	.signature=		"()Ljava/lang/Object;",
	.class=			&_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$type,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$param_ptypes$run$b190d7b16d5785b8,
	.signature_hash=	_JC_JLONG(0xb190d7b16d5785b8),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.function=		&_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$method$run$b190d7b16d5785b8,
	.vtable_index=		_JC_OFFSETOF(struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$vtable, org_w3c_dom_bootstrap_DOMImplementationRegistry__242.run$b190d7b16d5785b8) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .trap_table_len=	1,
	  .trap_table=		_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$trap_table$run$b190d7b16d5785b8,
	  .u= {
	    .linenum= {
	      .len=	3,
	      .table=	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$linenum_table$run$b190d7b16d5785b8
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(org_w3c_dom_bootstrap_DOMImplementationRegistry__242, run$b190d7b16d5785b8);

_jc_java_lang_Object$object * _JC_JCNI_ATTR
_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$method$run$b190d7b16d5785b8(_jc_env *const env, _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$object *this)
{
	struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$object *r0;
	struct _jc_java_lang_ClassLoader$object *volatile r1;
	struct _jc_java_lang_SecurityException$object *r3;
	struct _jc_java_lang_Thread$object *r4;
	_jc_catch_frame	catch;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	// Define exception targets
	_JC_DEFINE_TRAPS(env, catch, &_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$method_info$run$b190d7b16d5785b8, &&label0);

	r0 = this;
	_JC_LINE_NUMBER(323);				// 0
	r1 = _JC_NULL;
	_JC_TRAP_REGION(catch, 1);
	_JC_ACTIVE_USE(env, java_lang_Thread);
	_JC_LINE_NUMBER(325);				// 1
	r4 = _JC_INVOKE_STATIC(env, java_lang_VMThread, currentThread$d66ed2ac560d4c84, 0);
	r1 = _JC_INVOKE_VIRTUAL(env, java_lang_Thread, getContextClassLoader$8df97c408c9fbc5d, r4);
	_JC_TRAP_REGION(catch, 2);
	goto label1;

label0:
	_JC_TRAP_REGION(catch, 2);
	r3 = _JC_CAUGHT_EXCEPTION(env);

label1:
	_JC_LINE_NUMBER(329);				// 2
	_JC_CANCEL_TRAPS(env, catch);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$methods[] = {
	&_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$method_info$_init$52f4ad9f2989aeee,
	&_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$method_info$run$b190d7b16d5785b8
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$interfaces[] = {
	&_jc_java_security_PrivilegedAction$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$imethod_hash_bucket_56[] = {
	&_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$method_info$run$b190d7b16d5785b8,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[56]=	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$imethod_hash_bucket_56
};

// Interface "quick" lookup hash table
static const void *_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[56]=	&_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$method$run$b190d7b16d5785b8
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$instanceof_hash_bucket_20[] = {
	&_jc_java_security_PrivilegedAction$type,
	_JC_NULL
};
static _jc_type *const _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$instanceof_hash_bucket_56[] = {
	&_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$type,
	_JC_NULL
};
static _jc_type *const _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[20]=	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$instanceof_hash_bucket_20,
	[56]=	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$instanceof_hash_bucket_56,
	[101]=	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/ClassLoader",	_JC_JLONG(0x58c6b9c5ce1fc756) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/SecurityException",	_JC_JLONG(0x767fc1626c63609e) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/lang/Thread",	_JC_JLONG(0x7e33d4feabbc3f15) },
	{ "java/lang/Throwable",	_JC_JLONG(0x3be5c3c4fdd59a1e) },
	{ "java/lang/VMThread",	_JC_JLONG(0x8ee50e5570e2a2e1) },
	{ "java/security/PrivilegedAction",	_JC_JLONG(0xfe58a8cfe9b5b994) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$vtype _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$type = {
    .type= {
	.name=			"org/w3c/dom/bootstrap/DOMImplementationRegistry$2",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_FINAL,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$interfaces) / sizeof(*_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$interfaces),
	.interfaces=		_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$interfaces,
	.imethod_hash_table=	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$imethod_hash_table,
	.imethod_quick_table=	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x6b32cb9646ebd038),
		.source_file=		"DOMImplementationRegistry.java",
		.instance_size=		sizeof(_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$refs) + sizeof(_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$methods) / sizeof(*_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$methods),
		.methods=		_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$methods,
		.instanceof_hash_table=	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$class_depends) / sizeof(*_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$class_depends),
		.class_depends=		_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.org_w3c_dom_bootstrap_DOMImplementationRegistry__242= {
	    .run$b190d7b16d5785b8=
		&_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$method$run$b190d7b16d5785b8,
	},
    }
};
